@@ -19,10 +19,8 @@ from cogapp import Cog
 from paver.doctools import Includer, _cogsh
 from paver.easy import *  # noqa
 
-import sphinx
-
 import textwrap
-
+from pkg_resources import parse_version
 
 @task
 def html(options):
@@ -106,22 +104,18 @@ def pdf(options):
       the name of the command to use to make a PDF
       default: pdflatex
     """
-    run_sphinx(options, 'pdf')
+    rc = run_sphinx(options, 'pdf')
+    if rc:
+        print('skipping the rest of the build, sphinx returned', rc)
+        return rc
     options.order('pdf')
     pdflatex = options.get('pdflatex', 'pdflatex')
     paths = _get_paths(options)
-    latex_dir = paths.builddir / options.builder
-    sh('cd %s; PDFLATEX="%s" make -e' % (latex_dir, pdflatex))
+    outdir = options.get('outdir', paths.builddir / options.builder)
+    sh('cd %s; PDFLATEX="%s" make -e' % (outdir, pdflatex))
     return
 
 
-def _wrap_sphinx(sphinxopts):
-    try:
-        return sphinx.main(sphinxopts)
-    except SystemExit as e:
-        return e.code
-
-
 def run_sphinx(options, *option_sets):
     """Helper function to run sphinx with common options.
 
@@ -187,12 +181,12 @@ def run_sphinx(options, *option_sets):
         '-D%s=%s' % (name, value)
         for (name, value) in getattr(options, 'config_args', {}).items()
     ]
-    sphinxopts = [
-        '',
+    sphinxopts = []
+    sphinxopts.extend([
         '-b', options.get('builder', 'html'),
         '-d', paths.doctrees,
         '-c', paths.confdir,
-    ]
+    ])
 
     if options.get('force_all', False):
         sphinxopts.append('-a')
@@ -206,8 +200,7 @@ def run_sphinx(options, *option_sets):
     sphinxopts.extend(template_args)
     sphinxopts.extend(config_args)
     sphinxopts.extend([paths.srcdir, paths.outdir])
-    rc = dry("sphinx-build %s" % (" ".join(sphinxopts),),
-             _wrap_sphinx, sphinxopts)
+    rc = sh("sphinx-build {}".format(" ".join(sphinxopts)))
 
     options.order()
     return rc
@@ -282,6 +275,16 @@ def adjust_line_widths(lines, break_lines_at, line_break_mode):
                 textwrap.fill(l, width=break_lines_at).splitlines()
             )
 
+        elif line_break_mode == 'wrap-no-breaks':
+            broken_lines.extend(
+                textwrap.fill(
+                    l,
+                    width=break_lines_at,
+                    break_long_words=False,
+                    break_on_hyphens=False,
+                ).splitlines()
+            )
+
         elif line_break_mode == 'fill':
             prefix = l[:len(l) - len(l.lstrip())]
             broken_lines.extend(
@@ -365,6 +368,18 @@ def run_script(input_file, script_name,
            Insert a hard break with a backslash
          wrap
            Use textwrap.fill() to wrap
+         wrap-no-breaks
+           Use textwrap.fill() without breaking on hyphens
+           or long words
+         fill
+           Use textwrap.fill(), maintaining whitespace prefix
+           on subsequent lines
+         continue
+           Insert a hard break and backslash at the end of
+           long lines, continuing on the next
+         truncate
+           Chop the line at the required width and discard the
+           remainder
 
     adjust_python_for_version=True
       Boolean controlling whether the default `python`
@@ -404,6 +419,7 @@ def run_script(input_file, script_name,
     try:
         print()
         output_text = sh(real_cmd, capture=True, ignore_error=ignore_error)
+        print(output_text)
     except Exception as err:
         print('*' * 50)
         print('ERROR run_script(%s) => %s' % (real_cmd, err))
@@ -509,7 +525,7 @@ def _runcog(options, files, uncog=False):
             files = basedir.walkfiles(pattern)
         else:
             files = basedir.walkfiles()
-    for f in files:
+    for f in sorted(files):
         dry("cog %s" % f, c.processOneFile, f)
 
 
